// lib/movies.js
import axios from 'axios';

export async function getMovieById(id: string) { // Specify the type of 'id' as 'string'
  try {
    const response = await axios.get(
      `https://api.themoviedb.org/3/movie/${id}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
    );
    return response.data;
  } catch (error) {
    console.error("Failed to fetch movie data:", error);
    return null;
  }
}

// Updated function to fetch multiple pages of movies
export async function getAllMovies() {
  try {
    let allMovies: any[] = []; // Explicitly type the array
    const totalPages = 3; // Adjust this number based on how many movies you need

    for (let page = 1; page <= totalPages; page++) {
      const response = await axios.get(
        `https://api.themoviedb.org/3/movie/popular?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&language=en-US&page=${page}`
      );
      allMovies = [...allMovies, ...response.data.results];
    }

    return allMovies;
  } catch (error) {
    console.error("Failed to fetch movies list:", error);
    return [];
  }
}
